@@ -169,7 +169,10 @@ module GitalyServer
       branch_update = branch_update_result(result)
       Gitaly::UserCherryPickResponse.new(branch_update: branch_update)
     rescue Gitlab::Git::Repository::CreateTreeError => e
-      Gitaly::UserCherryPickResponse.new(create_tree_error: set_utf8!(e.message))
+      Gitaly::UserCherryPickResponse.new(
+        create_tree_error: set_utf8!(e.message),
+        create_tree_error_code: e.error.upcase
+      )
     rescue Gitlab::Git::CommitError => e
       Gitaly::UserCherryPickResponse.new(commit_error: set_utf8!(e.message))
     rescue Gitlab::Git::PreReceiveError => e
@@ -194,7 +197,10 @@ module GitalyServer
       branch_update = branch_update_result(result)
       Gitaly::UserRevertResponse.new(branch_update: branch_update)
     rescue Gitlab::Git::Repository::CreateTreeError => e
-      Gitaly::UserRevertResponse.new(create_tree_error: set_utf8!(e.message))
+      Gitaly::UserRevertResponse.new(
+        create_tree_error: set_utf8!(e.message),
+        create_tree_error_code: e.error.upcase
+      )
     rescue Gitlab::Git::CommitError => e
       Gitaly::UserRevertResponse.new(commit_error: set_utf8!(e.message))
     rescue Gitlab::Git::PreReceiveError => e
